Get a list of candidate URLs for a certain version of a package
cran_file(package, version, type = get_pkg_type(),
r_minor = r_minor_version(), cran_mirror = default_cran_mirror)Name of the package, e.g. jsonlite.
Version number of the package, as a string, e.g.
1.0.0.
Package type, e.g. binary, source, etc.
See the type argument of utils::install.packages.
The minor R version to search for packages for. Defaults to the currently running R version.
Character vector or URLs.